<?php
/**
 * The template for displaying Comments
 *
 * The area of the page that contains comments and the comment form.
 */

/*
 * If the current post is protected by a password and the visitor has not yet
 * entered the password we will return early without loading the comments.
 */
if ( post_password_required() ) return; ?>

<div id="comments" class="comments-area">
	<?php if ( have_comments() ) :/*comment list*/ ?>
		<h6 class="comment-total-title">
			<?php
				printf( /* WPCS: XSS OK.*/
					esc_html( _nx( '1 Comment', '%1$s Comments', get_comments_number(), 'comments title', 'minera') ),
					number_format_i18n( get_comments_number() ),
					'<span>' . get_the_title() . '</span>'
				);
			?>
		</h6>

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :/*comment navigation*/ ?>
			<nav id="comment-nav-above" class="navigation comment-navigation" role="navigation">
				<h3 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'minera'); ?></h3>
				<div class="nav-previous"><?php previous_comments_link( esc_html__( 'Older Comments', 'minera') ); ?></div>
				<div class="nav-next"><?php next_comments_link( esc_html__( 'Newer Comments ', 'minera') ); ?></div>
			</nav>
		<?php endif; ?>

		<div class="comment-list flw">
			<?php wp_list_comments( array( 'callback' => 'minera_comment_list' ) ); ?>
		</div>

	<?php endif; ?>
	<?php if ( ! comments_open() ) :/*comment disable*/ ?>
		<p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'minera'); ?></p>
	<?php else :/*comment form*/
		$commenter = wp_get_current_commenter();
		$req = get_option( 'require_name_email' );
		$aria_req = ( $req ? " aria-required='true'" : '' );
		$fields = array(
			'author' =>
				'<input id="author" type="text" name="author" placeholder="'.esc_attr__('Name *', 'minera').'" value="' . esc_attr( $commenter['comment_author'] ).'" '.$aria_req.'>',
			'email' =>
				'<input id="email" type="email" name="email" placeholder="'.esc_attr__('Email *', 'minera').'" value="' . esc_attr(  $commenter['comment_author_email'] )  . '" '.$aria_req.'>',
		);

		$args = array(
			'title_reply_before' => '<h6 id="reply-title" class="comment-reply-title">',
			'title_reply'          => esc_html__( 'Leave a reply', 'minera'),
			'title_reply_after' => '</h6>',
			'fields' => apply_filters( 'comment_form_default_fields', $fields ),
			'comment_field' =>  '<textarea id="comment" name="comment" placeholder="'.esc_attr__('Comment', 'minera').'" '.$aria_req.'>' . '</textarea>',
			'comment_notes_before' => '',
			'label_submit'         => esc_html__( 'Post Comment', 'minera'),
		);
		 comment_form($args); ?>
	<?php endif; ?>
</div>
