<?php
// @codingStandardsIgnoreStart
/* Helper functions and classes with static methods for usage in theme **/

/* WORDPRESS COMPONENTS *******************************************************/
{
	/*add new option for select svg logo*/
	add_action( 'customize_register', 'minera_customize_register', 11 );
	function minera_customize_register( $wp_customize ){
		$wp_customize->add_setting('logo_retina', array(
			'capability' => 'edit_theme_options',
			'type' => 'option'
		));

		$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'logo_retina', array(
			'label'    => esc_attr__('Logo Image Retina', 'minera'),
			'description' => esc_attr__('Select logo .svg your website', 'minera'),
			'section'  => 'c_general',
			'settings' => 'logo_retina',
			'priority' => 3
		)));
	}

	/*svg upload support*/
	function minera_svg_uploads($type){
		$new_type = array();
		$new_type['svg'] = 'image/svg+xml';

		$type = array_merge($type, $new_type );

		return $type;
	}
	add_action('upload_mimes', 'minera_svg_uploads');

	/*wp_link_pages*/
	if(!function_exists('minera_wp_link_pages')):
		function minera_wp_link_pages(){
			$args = array(
				'before' => '<div class="theme-page-links flw">',
				'after' => '</div>'
			);
			return wp_link_pages($args);
		}
	endif;

	/*tags*/
	function minera_filter_tag_cloud($args) {
		$args['smallest'] = 14;
		$args['largest'] = 14;
		$args['unit'] = 'px';
		$args['separator']= ', ';
		return $args;
	}
	add_filter ( 'widget_tag_cloud_args', 'minera_filter_tag_cloud');
	add_filter( 'woocommerce_product_tag_cloud_widget_args' , 'minera_filter_tag_cloud' );/*product tags*/

	/*remove `(` and `)` from the widget*/
	function minera_remove_parentheses_postcounts($variable) {
		$variable = str_replace('(', '<span class="widget-post-count">', $variable);
		$variable = str_replace(')', '</span>', $variable);
		return $variable;
	}
	add_filter('wp_list_categories','minera_remove_parentheses_postcounts');
	add_filter('get_archives_link', 'minera_remove_parentheses_postcounts');
	add_filter('woocommerce_layered_nav_count','minera_remove_parentheses_postcounts');

	/*replace more excerpt text*/
	function minera_more( $more ) {
		return '...';
	}
	add_filter( 'excerpt_more', 'minera_more' );

	/*remove query strings*/
	function minera_remove_query_string( $src ){
		$parts = explode( '?ver', $src );
		return $parts[0];
	}
	add_filter( 'script_loader_src', 'minera_remove_query_string', 15, 1 );
	add_filter( 'style_loader_src', 'minera_remove_query_string', 15, 1 );

	/*set content width*/
	if ( ! isset( $content_width ) ) $content_width = 1170;

	/*custom blog widget search form*/
	add_filter( 'get_search_form', 'minera_search_form_widget', 100 );
	function minera_search_form_widget( $form ) {
		$form = '<form role="search" method="get" class="search-form" action="' . esc_url(home_url( '/' )) . '" >';
		$form .= '<label class="screen-reader-text">' . esc_html__( 'Search for:', 'minera' ) . '</label>';
		$form .= '<input type="text" class="search-field" placeholder="'.esc_attr__('Search....', 'minera').'" value="' . get_search_query() . '" name="s" required/>';
		$form .= '<button type="submit" class="search-submit ht-ico-search"></button>';
		$form .= '</form>';
		return $form;
	}

	/*custom product widget search form*/
	add_filter( 'get_product_search_form' , 'minera_product_search_form_widget' );
	function minera_product_search_form_widget( $form ) {
		$form = '<form role="search" method="get" class="search-form" action="' . esc_url(get_permalink( wc_get_page_id( 'shop' ))) . '" >';
		$form .= '<label class="screen-reader-text">' . esc_html__( 'Search for:', 'minera' ) . '</label>';
		$form .= '<input type="text" class="search-field" placeholder="'.esc_attr__('Search....', 'minera').'" value="' . get_search_query() . '" name="s" required/>';
		$form .= '<button type="submit" class="search-submit ht-ico-search"></button>';
		$form .= '<input type="hidden" name="post_type" value="product">';
		$form .= '</form>';
		return $form;
	}

	/*Remove issues with prefetching adding extra views*/
	remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0);
}

/* OTHER PLUGIN CONFIG ********************************************************/
{
	/*EXTEND VISUAL COMPOSER ******************************************************/
	if ( class_exists( 'WPBakeryVisualComposerAbstract' ) ) {
		function minera_require_VC() {
			get_template_part('inc/vc', 'include');
		}
		add_action( 'init', 'minera_require_VC', 2 );
	}

	/*shop page: Change number of products displayed per page*/
	add_filter( 'loop_shop_per_page', 'minera_shop_page_number', 20 );
	function minera_shop_page_number( $cols ) {
		$cols = get_theme_mod('c_shop_ppp', 12);
		return $cols;
	}

	/*shop single: change related product number*/
	add_filter( 'woocommerce_output_related_products_args', 'minera_related_product_number' );
	function minera_related_product_number( $args ) {
		$args['posts_per_page'] = get_theme_mod('c_shop_single_related', 3);
		return $args;
	}

	/*shop view style switcher*/
	if(!function_exists('minera_shop_switcher')):
		function minera_shop_switcher($view_style = false){
			if($view_style == false) return;

			$list = $view_style == 'list' ? 'active' : '';
			$grid = $view_style == 'grid' ? 'active' : ''; ?>
			<div class="shop-sort-view">
				<span><?php esc_html_e('Filters', 'minera'); ?></span>
				<?php echo sprintf(
					'<button class="btn-switcher btn-view-list %s" data-style="list"></button>'.
					'<button class="btn-switcher btn-view-grid %s" data-style="grid"></button>',
					$list,
					$grid); ?>
			</div>
		<?php }
	endif;

	/*woocommerce cart item total on cart page*/
	function minera_woocommerce_cart_item_total_cart_page( $fragments ) {
		global $woocommerce;
		$count = $woocommerce->cart->cart_contents_count;
		ob_start(); ?>

		<span class="my-cart-total"><?php echo sprintf( esc_html__( 'My cart (%s Items)', 'minera'), $count ); ?></span>
		<?php $fragments['span.my-cart-total'] = ob_get_clean();

		return $fragments;
	}
	add_filter('woocommerce_add_to_cart_fragments', 'minera_woocommerce_cart_item_total_cart_page');

	/*woocommerce add empty cart button*/
	function minera_woo_clear_cart_url() {
		global $woocommerce;

		if ( isset( $_GET['empty-cart'] ) ) {
			$woocommerce->cart->empty_cart();
		}
	}
	add_action( 'init', 'minera_woo_clear_cart_url' );

	/*woocommerce single: renaming tabs*/
	function minera_woo_rename_tabs( $tabs ) {
		global $product;

		$count = $product->get_review_count();

		if(get_option( 'woocommerce_enable_reviews' ) == 'yes'){
			$tabs['reviews']['title'] = ($count == 0) ? esc_html__( 'Reviews', 'minera') :  sprintf(__( 'Reviews <span>%s</span>', 'minera'), $count );
		}

		return $tabs;
	}
	add_filter( 'woocommerce_product_tabs', 'minera_woo_rename_tabs', 98 );

	/*woocommerce account header action*/
	if(!function_exists('minera_account')):
		function minera_account(){
			if(class_exists('Woocommerce' )){
				$my_account_id = get_option( 'woocommerce_myaccount_page_id' );
				$order_id = get_option( 'woocommerce_view_order_page_id' );

				$logout_url = wp_logout_url( get_permalink( $my_account_id ) );
				if ( get_option( 'woocommerce_force_ssl_checkout' ) == 'yes' ) $logout_url = str_replace( 'http:', 'https:', $logout_url );

				if ( $my_account_id ) { ?>
					<div class="w-head-box" data-label="<?php esc_attr_e( 'Account', 'minera' ); ?>">
						<a href="<?php echo get_permalink( $my_account_id ); ?>" class="ht-ico-user theme-login-btn"></a>
						<ul class="w-head-action">
							<?php do_action( 'minera_account_before' ); ?>
							<?php if(!is_user_logged_in()){ ?>
								<li><a href="<?php echo get_permalink($my_account_id); ?>" class="text-center"><?php esc_html_e('Login / Register', 'minera'); ?></a></li>
							<?php }else{ ?>
								<li><a href="<?php echo get_permalink($my_account_id); ?>"><?php esc_html_e('Dashboard', 'minera'); ?></a></li>
								<li><a href="<?php echo esc_url($logout_url); ?>"><?php esc_html_e('Logout', 'minera'); ?></a></li>
							<?php } ?>
						</ul>
					</div>
				<?php }
			}
		}
	endif;

	/*enqueue main js swatches plugin*/
	function minera_woocommerce_product_variation() {
		$script_name = 'wc-add-to-cart-variation';
		if ( wp_script_is( $script_name, 'registered' ) && ! wp_script_is( $script_name, 'enqueued' ) ) {
			wp_enqueue_script( $script_name );
		}
	}
	add_action( 'wp_enqueue_scripts', 'minera_woocommerce_product_variation' );

	/*remove some css no need*/
	function minera_dequeue_css() {
		/*swatch variation product*/
		wp_dequeue_style('tawcvs-frontend');
		/*woocommerce css yith====*/
		wp_dequeue_style('yith-wcwl-main');
		wp_dequeue_style('yith-wcwl-font-awesome');
		wp_dequeue_style('yith-quick-view');
		wp_dequeue_style('jquery-selectBox');
		/*visual composer*/
		wp_dequeue_style('font-awesome');
	}
	add_action('wp_enqueue_scripts','minera_dequeue_css', 100);

	/*Remove Rev Slider Metabox*/
	if ( is_admin() ) {
		function minera_remove_rev_slider_meta_boxes($post_type){
			add_action('do_meta_boxes', function () use ($post_type) {
				remove_meta_box('mymetabox_revslider_0', $post_type, 'normal');
			});
		}
		add_action('registered_post_type', 'minera_remove_rev_slider_meta_boxes');
	}

	/*remove css of contact form 7====*/
	add_filter( 'wpcf7_load_css', '__return_false' );
	/*Contact form 7: Disable the configuration validator*/
	add_filter( 'wpcf7_validate_configuration', '__return_false' );

	/*woocommerce: remove css default*/
	add_filter( 'woocommerce_enqueue_styles', '__return_empty_array' );

	/*call shopping cart*/
	function minera_shopping_cart($only_icon = true, $icon = 'ht-ico-cart'){
		if(!class_exists('Woocommerce')) return;

		global $woocommerce;
		$total_item = $woocommerce->cart->cart_contents_count;
		$total_price = $woocommerce->cart->get_cart_total(); ?>

		<div class="theme-shopping-cart" data-label="<?php esc_attr_e( 'Cart', 'minera' ); ?>">
			<?php if($only_icon == true): ?>
				<a class="<?php echo esc_attr($icon); ?> shopping-cart-icon" href="<?php echo wc_get_cart_url(); ?>" title="<?php esc_attr_e( 'View your shopping cart', 'minera' ); ?>">
					<span class="counter-cart"><?php echo esc_html($total_item); ?></span>
				</a>
			<?php else: ?>
				<div class="cart-price-total">
					<span class="cart-price-txt"><?php esc_html_e('Cart:', 'minera'); ?></span>
					<?php echo wp_kses_post($total_price); ?>
				</div>
			<?php endif; ?>
		</div>
	<?php }

	/*shopping cart - total item*/
	function minera_cart_total_item( $fragments ) {
		global $woocommerce;
		$total_item = $woocommerce->cart->cart_contents_count;
		ob_start(); ?>
		<span class="counter-cart"><?php echo esc_html($total_item); ?></span>
		<?php $fragments['span.counter-cart'] = ob_get_clean();
		return $fragments;
	}
	add_filter('woocommerce_add_to_cart_fragments', 'minera_cart_total_item');


	/*shopping cart - total price*/
	function minera_cart_total_price( $fragments ) {
		global $woocommerce;
		$total_price = $woocommerce->cart->get_cart_total();
		ob_start(); ?>
		<strong class="cart-price-total">
			<span class="cart-price-txt"><?php esc_html_e('Cart', 'minera'); ?></span>
			<?php echo wp_kses_post($total_price); ?>
		</strong>
		<?php $fragments['strong.cart-price-total'] = ob_get_clean();
		return $fragments;
	}
	add_filter('woocommerce_add_to_cart_fragments', 'minera_cart_total_price');

	/*shopping cart - list item*/
	function minera_cart_list($fragments) {
		global $woocommerce;
		$total_item = $woocommerce->cart->cart_contents_count;
		ob_start(); ?>
			<div class="cart-sidebar-content">
				<?php woocommerce_mini_cart(); ?>
			</div>
		<?php
		$fragments['div.cart-sidebar-content'] = ob_get_clean();
		return $fragments;
	}
	add_filter( 'woocommerce_add_to_cart_fragments', 'minera_cart_list');


    /* CHECK OPTION AJAX ADD TO CART ON OR OFF
    ***************************************************/
    if( ! function_exists( 'minera_ajax_act_opt' ) ):
        function minera_ajax_act_opt(){
            return 'yes' == get_option( 'woocommerce_enable_ajax_add_to_cart' ) ? 'ajax_add_to_cart' : '';
        }
    endif;

    /* DETECT WC_PRODUCT_ADDONS INSTALL
    ***************************************************/
    if( ! function_exists( 'minera_wc_addons' ) ):
        function minera_wc_addons(){
            return defined( 'WC_PRODUCT_ADDONS_VERSION' );
        }
    endif;

    /*ADD A CUSTOM COLUMN IN POSTS AND CUSTOM POST TYPES ADMIN SCREEN*/
        /*GET FEATURED IMAGE*/
        function minera_get_featured_image($post_ID) {
            $img_id = get_post_thumbnail_id($post_ID);
            if ($img_id) {
                $img_src = wp_get_attachment_image_src($img_id, 'thumbnail');
                return $img_src[0];
            }
        }
        /*ADD NEW COLUMN*/
        add_filter('manage_post_posts_columns', 'minera_columns_head', 10);
        function minera_columns_head($defaults) {
            $order = array();
            /* `cb` = checkbox*/
            $checkbox = 'cb';
            foreach($defaults as $key => $value) {
                $order[$key] = $value;
                if ($key == $checkbox){
                    $order['thumbnail_image'] = esc_attr__('Image', 'minera');
                }
            }
            return $order;
        }
        /*SHOW THE FEATURED IMAGE*/
        add_action('manage_post_posts_custom_column', 'minera_columns_content', 10, 2);
        function minera_columns_content($column_name, $post_ID) {
            if ($column_name == 'thumbnail_image') {
                $_img_src = minera_get_featured_image($post_ID);
                if ($_img_src) { ?>
                    <a href="<?php echo get_edit_post_link($post_ID) ?>">
                        <img src="<?php echo esc_url($_img_src); ?>" />
                    </a>
                <?php }else{ ?>
                    <a href="<?php echo get_edit_post_link($post_ID) ?>">
                        <img src="<?php echo get_template_directory_uri() . '/images/thumbnail-default.jpg'; ?>" />
                    </a>
                <?php }
            }
        }
}

/* THEME CUSTOMIZATION ********************************************************/
{
	/*group blog detect*/
	if(!function_exists('minera_blog')):
		function minera_blog() {
			global $post;
			$post_type = get_post_type($post );
			return ( (is_archive() || is_author() || is_category() || is_home() || is_single() || is_tag()) && $post_type == 'post' ) ? true : false;
		}
	endif;

	/*sidebar menu*/
	if(!function_exists('minera_sidebar_menu')):
		function minera_sidebar_menu($sidebar_menu_id, $sidebar_menu){
			if($sidebar_menu_id == 'disable') return;

			$head = get_theme_mod('sidebar_top', 'An Exquisite Minimal Plant Store');
			$foot = get_theme_mod('sidebar_foot',
			'<p>&copy; 2017 <a href="#"><strong>Minera</strong></a>. All Rights Reserved.</p>
			<ul class="social-list theme-social-icon">
			<li><a href="//facebook.com/minera"></a></li>
			<li><a href="//twitter.com/minera"></a></li>
			<li><a href="//pinterest.com/minera"></a></li>
			</ul>');

			if(!empty($sidebar_menu)){
				echo '<span id="sidebar-menu-btn"><span></span></span>';

				echo '<div class="box-sidebar-menu">';
				if(!empty($head)):
					echo '<div class="sidebar-menu-head">'. wp_kses_decode_entities($head) .'</div>';
				endif;
					minera_edit_location('sidebar_menu');/*sidebar menu edit location*/
					wp_nav_menu(array('menu' => $sidebar_menu_id, 'menu_class' => 'theme-sidebar-menu', 'container' => ''));
				if(!empty($foot)):
					echo '<div class="sidebar-menu-foot">'. wp_kses_decode_entities($foot) .'</div>';
				endif;
				echo '</div>';
			}else{ ?>
				<a class="add-menu" href="<?php echo esc_url( get_admin_url() . 'nav-menus.php' ); ?>"><?php esc_html_e( 'Add Sidebar Menu', 'minera' ); ?></a>
			<?php }
		}
	endif;

	/*Show attribute swatches list*/
	if ( ! function_exists( 'minera_swatches_list' ) ) {
		function minera_swatches_list( $size = 'woocommerce_thumbnail' ) {

			if ( false == get_theme_mod( 'product_swatch', true ) ) {
				return;
			}

			global $product;

			$pid = $product->get_id();

			if( empty( $pid ) || ! $product->is_type( 'variable' ) ) return;


			$default_attr = method_exists( $product, 'get_default_attributes' ) ? $product->get_default_attributes() : array();

			$vars = $product->get_available_variations();

			$attributes = $product->get_attributes();

			if(empty($attributes)) return;

			foreach($attributes as $key){
				$attr_name = $key['name'];/*swatches type*/
				$terms = wc_get_product_terms( $pid, $attr_name, array( 'fields' => 'all' ) );

				/*get type of product attribute by id*/
				$attr_type = wc_get_attribute( $key['id'] );

				if(empty($terms)) return;

				$id_slug = $name_slug = array();

				foreach($terms as $val){
					$id_slug[$val->term_id] = $val->slug;
					$id_name[$val->name] = $val->slug;
				}

				/*check atrribute*/
				$color = $img_id = '';
				$empty_arr = array();

				$attr_name = strtolower( urlencode( $attr_name ) );
				foreach($vars as $key){
					$slug = isset($key['attributes']['attribute_' . $attr_name]) ? $key['attributes']['attribute_' . $attr_name] : '';

					if( ! in_array( $slug, $empty_arr ) ){
						array_push( $empty_arr, $slug );
					}else{
						continue;
					}

					if( empty( $slug ) ) continue;

					$_id = array_search( $slug, $id_slug );
					$name = array_search( $slug, $id_name );
					$src = wp_get_attachment_image_src( $key['image_id'], $size );
					$_class = ( isset( $default_attr[$attr_name] ) && $slug == $default_attr[$attr_name] ) ? 'active' : '';

					switch( $attr_type->type ){
						case 'color':
							$color = get_term_meta( $_id, 'color', true );
							echo '<span class="p-attr-swatch p-attr-color '. esc_attr( $_class) .'" title="'. esc_attr( $name ) .'" data-src="'. esc_attr( $src[0] ) .'" style="background-color:'. esc_attr( $color ) .'"></span>';
							break;
						case 'image':
							$img_id = get_term_meta( $_id, 'image', true );
							$img_alt = minera_img_alt( $img_id, esc_attr__( 'Swatch image', 'minera' ) );
							echo '<span class="p-attr-swatch p-attr-image '. esc_attr( $_class) .'" title="'. esc_attr( $name ) .'" data-src="'. esc_attr( $src[0] ) .'"><img src="' . wp_get_attachment_url( $img_id ) . '" alt="'. esc_attr( $img_alt ) .'"></span>';
							break;
					}
				}
			}
		}
	}

	/*check product already in cart*/
	if(!function_exists('minera_product_in_cart')):
		function minera_product_in_cart($pid){
			global $woocommerce;
			$_cart = $woocommerce->cart->get_cart();

			foreach($_cart as $key){
				$_product = $key['data'];

				if($_product->get_id() == $pid){
					return true;
				}
			}

			return false;
		}
	endif;

	/*get product quantity in cart*/
	if(!function_exists('minera_product_qty_in_cart')):
		function minera_product_qty_in_cart($pid){
			global $woocommerce;
			$_cart = $woocommerce->cart->get_cart();

			foreach ( $_cart as $key ) {
				if($key['product_id'] == $pid ){
					$qty = $key['quantity'];
					break;
				}
			}
			return $qty;
		}
	endif;

	/*AJAX - ADMIN URL*/
		add_action('wp_enqueue_scripts', 'minera_ajax_url', 999);
		function minera_ajax_url(){
			wp_localize_script(
				'minera-theme-script',
				'admin_ajax',
				array(
					'url'   => admin_url( 'admin-ajax.php' ),
					'nonce' => wp_create_nonce( 'minera_ajax_nonce' ),
				)
			);
		}

	/*AJAX - PRODUCT QUICK VIEW*/
		add_action('wp_ajax_quickview_action', 'minera_quickview_content');
		add_action('wp_ajax_nopriv_quickview_action', 'minera_quickview_content');
		function minera_quickview_content() {
			check_ajax_referer( 'minera_ajax_nonce', 'nonce', false );

			if( !isset( $_POST['product_id'] )) {
				exit();
			}
			/*Setup query*/
			$product_id = sanitize_text_field( wp_unslash( $_POST['product_id'] ) );
			/*set the main wp query for the product id*/
			wp( 'p=' . $product_id . '&post_type=product' );

			/*cache*/
			ob_start();

			while ( have_posts() ) : the_post(); ?>
				<div id="product-<?php the_ID(); ?>" <?php post_class('product'); ?> >
					<?php
						/* get swatch html */
						add_filter( 'woocommerce_dropdown_variation_attribute_options_html', 'minera_get_swatch_html', 10, 2 );
						function minera_get_swatch_html( $html, $args ) {

							/* return `$html` when `WooCommerce Variation Swatches` plugin not installed */
							if(!function_exists('TA_WCVS')) return $html;

							$swatch_types = TA_WCVS()->types;
							$attr         = TA_WCVS()->get_tax_attribute( $args['attribute'] );

							/* Return if this is normal attribute */
							if ( empty( $attr ) ) {
								return $html;
							}

							if ( ! array_key_exists( $attr->attribute_type, $swatch_types ) ) {
								return $html;
							}

							$options   = $args['options'];
							$product   = $args['product'];
							$attribute = $args['attribute'];
							$class     = "variation-selector variation-select-{$attr->attribute_type}";
							$swatches  = '';

							if ( empty( $options ) && ! empty( $product ) && ! empty( $attribute ) ) {
								$attributes = $product->get_variation_attributes();
								$options    = $attributes[$attribute];
							}

							if ( array_key_exists( $attr->attribute_type, $swatch_types ) ) {
								if ( ! empty( $options ) && $product && taxonomy_exists( $attribute ) ) {
									/* Get terms if this is a taxonomy - ordered. We need the names too. */
									$terms = wc_get_product_terms( $product->get_id(), $attribute, array( 'fields' => 'all' ) );

									foreach ( $terms as $term ) {
										if ( in_array( $term->slug, $options ) ) {
											$swatches .= apply_filters( 'tawcvs_swatch_html', '', $term, $attr, $args );
										}
									}
								}

								if ( ! empty( $swatches ) ) {
									$class .= ' hidden';

									$swatches = '<div class="tawcvs-swatches" data-attribute_name="attribute_' . esc_attr( $attribute ) . '">' . $swatches . '</div>';
									$html     = '<div class="' . esc_attr( $class ) . '">' . $html . '</div>' . $swatches;
								}
							}

							return $html;
						}

						/* print html watch */
						add_filter( 'tawcvs_swatch_html', 'minera_swatch_html', 5, 4 );
						function minera_swatch_html( $html, $term, $attr, $args ) {
							/* return `$html` when `WooCommerce Variation Swatches` plugin not installed */
							if(!function_exists('TA_WCVS')) return $html;

							$selected = sanitize_title( $args['selected'] ) == $term->slug ? 'selected' : '';
							$name     = esc_html( apply_filters( 'woocommerce_variation_option_name', $term->name ) );

							switch ( $attr->attribute_type ) {
								case 'color':
									$color = get_term_meta( $term->term_id, 'color', true );
									list( $r, $g, $b ) = sscanf( $color, "#%02x%02x%02x" );
									$html = sprintf(
										'<span class="swatch swatch-color swatch-%s %s" style="background-color:%s;color:%s;" title="%s" data-value="%s">%s</span>',
										esc_attr( $term->slug ),
										$selected,
										esc_attr( $color ),
										"rgba($r,$g,$b,0.5)",
										esc_attr( $name ),
										esc_attr( $term->slug ),
										$name
									);
									break;

								case 'image':
									$image = get_term_meta( $term->term_id, 'image', true );
									$image = $image ? wp_get_attachment_image_src( $image ) : '';
									$image = $image ? $image[0] : WC()->plugin_url() . '/assets/images/placeholder.png';
									$html  = sprintf(
										'<span class="swatch swatch-image swatch-%s %s" title="%s" data-value="%s"><img src="%s" alt="%s">%s</span>',
										esc_attr( $term->slug ),
										$selected,
										esc_attr( $name ),
										esc_attr( $term->slug ),
										esc_url( $image ),
										esc_attr( $name ),
										esc_attr( $name )
									);
									break;

								case 'label':
									$label = get_term_meta( $term->term_id, 'label', true );
									$label = $label ? $label : $name;
									$html  = sprintf(
										'<span class="swatch swatch-label swatch-%s %s" title="%s" data-value="%s">%s</span>',
										esc_attr( $term->slug ),
										$selected,
										esc_attr( $name ),
										esc_attr( $term->slug ),
										esc_html( $label )
									);
									break;
							}

							return $html;
						}
					?>
					<?php do_action( 'woocommerce_before_single_product_summary' ); ?>
					<div class="w-summary-box summary entry-summary">
						<?php do_action( 'woocommerce_single_product_summary' ); ?>
					</div>
				</div>
			<?php endwhile;

			echo ob_get_clean();

			exit();
		}

	/*AJAX - BLOG PAGINATION*/
		add_action('wp_enqueue_scripts', 'minera_blog_paging_ajax', 1000);
		function minera_blog_paging_ajax(){
			if(minera_blog() || is_search()):
				global $wp_query;
				wp_localize_script('minera-theme-script', 'blog_posts_data', array(
					'posts' => json_encode($wp_query->query_vars),
					'current_page' => get_query_var( 'paged' ) ? get_query_var( 'page' ) : 1,
					'max_page' => $wp_query->max_num_pages,
					'load_more_posts' => esc_html__( 'Load more posts', 'minera' ),
					'loading_text' => esc_html__( 'Loading...', 'minera' ),
					'no_posts_found' => esc_html__( 'No posts found', 'minera' )
				));
			endif;
		}
		/*wp hooks*/
		add_action('wp_ajax_blog_posts_action', 'minera_blog_paging_action');
		add_action('wp_ajax_nopriv_blog_posts_action', 'minera_blog_paging_action');
		function minera_blog_paging_action(){
			check_ajax_referer( 'minera_ajax_nonce', 'nonce' );

			$args = json_decode(sanitize_text_field(stripslashes($_POST['query'])), true);
			$args['paged'] = sanitize_text_field( wp_unslash( $_POST['page'] ) ) + 1;
			$args['post_status'] = 'publish';

			query_posts( $args );

			if(have_posts()):
				while(have_posts()):
					the_post();

					if(class_exists('WPBMap') && method_exists('WPBMap', 'addAllMappedShortcodes')){
						/*remove vc shortcode in ajax response*/
						WPBMap::addAllMappedShortcodes();
					}

					get_template_part( 'content', get_post_format());
				endwhile;
			endif;

			exit();
		}

	/*AJAX - SINGLE ADD TO CART*/
		add_action( 'wp_ajax_atc', 'minera_single_add_to_cart' );
		add_action( 'wp_ajax_nopriv_atc', 'minera_single_add_to_cart' );
		function minera_single_add_to_cart() {
			check_ajax_referer( 'minera_ajax_nonce', 'nonce', false );
			$response = array();

			if( !isset( $_POST['product_id'] )) {
				wp_send_json_error();
				exit();
			}
			$product_id = sanitize_text_field( wp_unslash( $_POST['product_id'] ) );
			$product    = wc_get_product( $product_id );

			if(isset($_POST['variation_id'])){
				$variation_id = sanitize_text_field( wp_unslash( $_POST['variation_id'] ) );
			}

			if(isset($_POST['quantity'])){
				$quantity = sanitize_text_field( wp_unslash( $_POST['quantity'] ) );
				$passed_validation = apply_filters( 'woocommerce_add_to_cart_validation', true, $product_id, $quantity );
			}

			if(isset($_POST['variations'])){
				$variations = wp_unslash( $_POST['variations'] );
			}

			if ($variation_id && $passed_validation) {
				WC()->cart->add_to_cart( $product_id, $quantity, $variation_id, $variations );
			} else {
				WC()->cart->add_to_cart( $product_id, $quantity );
			}

			$count        = WC()->cart->get_cart_contents_count();
			$_in_cart_qty = minera_product_qty_in_cart( $product_id );

			ob_start();
			woocommerce_mini_cart();
			$response['variation_id'] = $variation_id;
			$response['variations']   = $variations;
			$response['in_cart']      = minera_product_qty_in_cart( $product_id );
			$response['count']        = WC()->cart->get_cart_contents_count();
			$response['content']      = ob_get_clean();

			wp_send_json( $response );

			exit();
		}

	/*loading effect*/
	if(!function_exists('minera_loading_effect')):
		function minera_loading_effect(){
			if(get_theme_mod('loading', false) == true): ?>
				<div id="page-loader"></div>
			<?php endif;
		}
	endif;

	/*img alt*/
	if(!function_exists('minera_img_alt')):
		function minera_img_alt($id = null, $alt = '' ){
			$img_alt = (get_post_meta($id,'_wp_attachment_image_alt', true) != '') ? get_post_meta($id,'_wp_attachment_image_alt', true) : $alt;
			return $img_alt;
		}
	endif;

	/*blog categories*/
	if(!function_exists('minera_blog_categories')):
		function minera_blog_categories(){
			$categories_string = '';
			$categories = get_the_category();
			$separator = ', ';
			$output = '';
			if ( ! empty( $categories ) ) {
				foreach( $categories as $category ) {
					$output .= '<a href="' . esc_url( get_category_link( $category->term_id ) ) . '" title="' . esc_attr( sprintf( esc_html__( 'View all posts in %s', 'minera'), $category->name ) ) . '">' . esc_html( $category->name ) . '</a>' . $separator;
				}
				$categories_string .= trim( $output, $separator );
			}
			return $categories_string;
		}
	endif;

	/*relative comment time*/
	if(!function_exists('minera_relative_time')):
		function minera_relative_time($type = 'comment') {
			$time = ('comment' == $type) ? 'get_comment_time' : 'get_post_time';
			return human_time_diff($time('U'), current_time('timestamp')) . " " . esc_html__('ago', 'minera');
		}
	endif;

	/*blog pagination*/
	if (!function_exists( 'minera_paging' ) ) :
		function minera_paging( $wp_query = null ) {

			if ( ! $wp_query ) {
				$wp_query = $GLOBALS['wp_query'];
			}

			/*Don't print empty markup if there's only one page.*/

			if ( $wp_query->max_num_pages < 2 ) {
				return;
			}

			$paged        = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
			$pagenum_link = html_entity_decode( get_pagenum_link() );
			$query_args   = array();
			$url_parts    = explode( '?', $pagenum_link );

			if ( isset( $url_parts[1] ) ) {
				wp_parse_str( $url_parts[1], $query_args );
			}

			$pagenum_link = remove_query_arg( array_keys( $query_args ), $pagenum_link );
			$pagenum_link = trailingslashit( $pagenum_link ) . '%_%';

			$format = $GLOBALS['wp_rewrite']->using_index_permalinks() && ! strpos( $pagenum_link,
				'index.php' ) ? 'index.php/' : '';
			$format .= $GLOBALS['wp_rewrite']->using_permalinks() ? user_trailingslashit( 'page/%#%',
				'paged' ) : '?paged=%#%';

			/*Set up paginated links.*/
			$links = paginate_links( array(
				'base'      => $pagenum_link,
				'format'    => $format,
				'total'     => $wp_query->max_num_pages,
				'current'   => $paged,
				'mid_size'  => 1,
				'add_args'  => array_map( 'urlencode', $query_args ),
				'prev_text' => esc_html__('Prev', 'minera'),
				'next_text' => esc_html__('Next', 'minera'),
				'type'      => 'list'
			) );

			if ( $links ) : ?>
				<nav class="ht-pagination">
					<span class="screen-reader-text"><?php esc_html_e( 'Posts pagination', 'minera'); ?></span>
					<?php echo wp_kses_post($links); ?>
				</nav>
			<?php endif;
		}
	endif;

	/*post date*/
	if (!function_exists( 'minera_post_date' ) ) :
		function minera_post_date() {
			$post_info = get_the_date(get_option('date_format'));
			return $post_info;
		}
	endif;

	/*blog post info*/
	if(!function_exists('minera_post_info')){
		function minera_post_info(){
			global $post; ?>
			<ul class="blog-post-info">
				<li itemprop="datePublished" content="<?php echo get_the_time('c'); ?>" class="if-time">
					<?php echo minera_post_date();/*post date*/ ?>
				</li>
				<li itemprop="author" class="if-author">
					<span><?php esc_html_e('by ', 'minera'); ?></span>
					<?php the_author_posts_link(); ?>
				</li>
				<li itemprop="commentCount" class="if-comment">
					<a href="<?php echo get_comments_link($post->ID); ?>">
						<?php if(get_comments_number() == 1){
							echo get_comments_number() . esc_html__( ' Comment', 'minera' );
						}else{
							echo get_comments_number() . esc_html__( ' Comments', 'minera' );
						} ?>
					</a>
				</li>
				<li class="if-cate"><?php echo minera_blog_categories(); ?></li>
			</ul>
		<?php }
	}

	/*Author Card*/
	if(!function_exists('minera_author_card')){
		function minera_author_card(){
			if ( empty( $post ) && isset( $GLOBALS['post'] ) )
			$post = $GLOBALS['post'];
			$authordesc = get_the_author_meta( 'description' );
			if(!empty($authordesc)): ?>
				<div class="flw screen-reader-text" itemscope itemtype="https://schema.org/CreativeWork">
					<div class="post-author-info-single" itemprop="author" itemscope itemtype="http://schema.org/Person">
						<div class="author-av"><?php echo get_avatar( $post->ID, $size = 123 ); ?></div>
						<div class="post-author-detail">
							<strong class="author-name" itemprop="name"><?php the_author(); ?></strong>
							<p class="author-desc" itemprop="description"><?php the_author_meta('description'); ?></p>
						</div>
					</div>
				</div><?php
			endif;
		}
	}

	/*Print the attached image with a link to the next attached image - in image.php*/
	if (!function_exists('minera_the_attached_image') ){
		function minera_the_attached_image() {
			$post = get_post();
			$next_attachment_url = wp_get_attachment_url();
			$attachment_ids = get_posts( array(
				'post_parent'    => $post->post_parent,
				'fields'         => 'ids',
				'numberposts'    => - 1,
				'post_status'    => 'inherit',
				'post_type'      => 'attachment',
				'post_mime_type' => 'image',
				'order'          => 'ASC',
				'orderby'        => 'menu_order ID',
			) );
			// If there is more than 1 attachment in a gallery...
			if ( count( $attachment_ids ) > 1 ) {
				foreach ( $attachment_ids as $attachment_id ) {
					if ( $attachment_id == $post->ID ) {
						$next_id = current( $attachment_ids );
						break;
					}
				}
				// get the URL of the next image attachment...
				if ( $next_id ) {
					$next_attachment_url = get_attachment_link( $next_id );
				} // or get the URL of the first image attachment.
				else {
					$next_attachment_url = get_attachment_link( array_shift( $attachment_ids ) );
				}
			}
			printf( '<a href="%1$s" rel="attachment">%2$s</a>',
				esc_url( $next_attachment_url ),
				wp_get_attachment_image( $post->ID, 'full')
			);
		}
	}

	/*comment output*/
	if(!function_exists('minera_comment_list')):
		function minera_comment_list($comment, $args, $depth){
			$GLOBALS['comment'] = $comment;
			switch ( $comment->comment_type ) :
				case 'pingback' :
				case 'trackback' : ?>
				<div class="comment-post-pingback">
					<span><?php esc_html_e( 'Pingback:', 'minera' ); ?></span><?php comment_author_link(); ?><?php edit_comment_link(esc_html__( 'Edit', 'minera' )); ?>
				</div>
			<?php
				break;
				default :
			?>
				<div id="comment-<?php comment_ID(); ?>" class="comment-item" itemscope itemtype="http://schema.org/Comment">
					<div class="comment-avatar">
						<?php echo get_avatar($comment, $size = '70'); ?>
					</div>
					<div class="comment-content">
						<strong class="comment-author" itemprop="creator">
							<a href="#comment-<?php comment_ID(); ?>" itemprop="discussionUrl" class="comment-author-name"><?php echo get_comment_author(); ?></a>
						</strong>
						<div class="comment-time" itemprop="datePublished" content="<?php echo get_the_time('c'); ?>"><?php
							echo minera_relative_time();/*relative comment time*/ ?></div>
						<div class="comment-text" itemprop="about">
							<?php if ($comment->comment_approved == '0') : ?>
								<em><?php esc_html_e('Your comment is awaiting moderation.', 'minera') ?></em>
							<?php endif; ?>
							<?php comment_text(); ?>
						</div>
						<?php echo get_comment_reply_link(array_merge($args,array(
							'depth' => $depth,
							'reply_text' => esc_html__('Reply', 'minera'),
							'max_depth' => $args['max_depth'])));
						?>
						<?php edit_comment_link(esc_html__('Edit', 'minera'), '  ', '') ?>
					</div>
				</div>
			<?php
				break;
			endswitch;
		}
	endif;

	/*blog post thumbnail*/
	if(!function_exists('minera_post_thumbnail')):
		function minera_post_thumbnail($size = 'large'){
			global $post;
			$thumbnail = get_the_post_thumbnail_url($post->ID, $size);
			if(!empty($thumbnail)):
				$img_id  = get_post_thumbnail_id($post->ID);
				$img_alt = minera_img_alt($img_id, 'Blog thumbnail'); ?>
				<a href="<?php the_permalink(); ?>" class="blog-post-cover" itemprop="image" itemscope itemtype="http://schema.org/ImageObject">
					<img src="<?php echo esc_url($thumbnail); ?>" alt="<?php echo esc_attr($img_alt); ?>">
					<meta itemprop="url" content="<?php echo esc_url($thumbnail); ?>" />
					<meta itemprop="width" content="840" />
					<meta itemprop="height" content="400" />
				</a>
			<?php endif;
		}
	endif;

	/*blog single option for post info*/
	if(!function_exists('minera_single_post_info')):
		function minera_single_post_info(){
			global $post;
			$blog_info_style = (function_exists('fw_get_db_post_option') ? fw_get_db_post_option($post->ID, 'p_blog_info') : 'left');

			/*default post title*/
			$default_title = get_the_title();
			$post_title = !empty($default_title) ? get_the_title() : 'This post has no title';

			if(!is_single()){
				minera_post_info();/*blog post info: datetime, author, comments*/ ?>
				<h4 class="post-tit" itemprop="headline">
					<a itemprop="url" href="<?php the_permalink(); ?>"><?php echo esc_html($post_title); ?></a>
				</h4>
			<?php }else{ ?>
				<div class="blog-top-info b-info-single with-<?php echo esc_attr($blog_info_style); ?>">
					<?php minera_post_info();/*blog post info: datetime, author, comments*/ ?>
				</div>
		<?php }
		}
	endif;

	/*port format options*/
	if(!function_exists('minera_post_format_options')):
		function minera_post_format_options(){
			if(is_single()):/*post format only show in single post*/
				global $post;
				$format = get_post_format( $post->ID );
				switch($format){
					case 'video' :
						$video_type = (function_exists('fw_get_db_post_option') ? fw_get_db_post_option($post->ID, 'video_type') : '');
						$video_id = (function_exists('fw_get_db_post_option') ? fw_get_db_post_option($post->ID, 'video_id') : '');
						if(!empty($video_id)): ?>
							<div class="single-format-content pf-video">
								<div data-type="<?php echo esc_attr($video_type); ?>" data-video-id="<?php echo esc_attr($video_id); ?>" class="p-video"></div>
							</div>
						<?php endif;
						break;
					case 'image' :
						$image = (function_exists('fw_get_db_post_option')) ? fw_get_db_post_option($post->ID, 'd_image') : '';
						if(!empty($image)): ?>
							<div class="single-format-content pf-image">
								<?php $img_alt = minera_img_alt($image['attachment_id'], 'Image'); ?>
								<img src="<?php echo esc_url($image['url']); ?>" alt="<?php echo esc_attr($img_alt); ?>">
							</div>
						<?php endif;
						break;
					case 'link' :
						$link_title = (function_exists('fw_get_db_post_option') ? fw_get_db_post_option($post->ID, 'link_title') : '');
						$link_url = (function_exists('fw_get_db_post_option') ? fw_get_db_post_option($post->ID, 'link_url') : '');
						if(!empty($link_url)): ?>
							<div class="single-format-content pf-link">
								<a href="<?php echo esc_url($link_url); ?>"><?php
									if(!empty($link_title)){
										echo esc_html($link_title);
									}else{
										echo esc_html($link_url);
									}
								?></a>
							</div>
						<?php endif;
						break;
					case 'gallery' :
						$gallery = (function_exists('fw_get_db_post_option')) ? fw_get_db_post_option($post->ID, 'd_gallery') : '';
						if(!empty($gallery)): ?>
							<div class="single-format-content pf-gallery">
								<?php foreach($gallery as $key){
									$imgs_alt = (get_post_meta($key['attachment_id'],'_wp_attachment_image_alt', true) != '') ? get_post_meta($key['attachment_id'],'_wp_attachment_image_alt', true) : 'Gallery image';
									echo '<img src="' . esc_url($key['url']) . '" alt="' . esc_attr($imgs_alt) . '" />';
								} ?>
							</div>
						<?php endif;
						break;
					case 'quote' :
						$d_quote = (function_exists('fw_get_db_post_option') ? fw_get_db_post_option($post->ID, 'd_quote') : '');
						if(!empty($d_quote)): ?>
							<div class="single-format-content pf-quote">
								<blockquote><?php echo esc_html($d_quote); ?></blockquote>
							</div>
						<?php endif;
						break;
					case 'audio' :
						$d_audio = (function_exists('fw_get_db_post_option') ? fw_get_db_post_option($post->ID, 'd_audio') : '');
						if(!empty($d_audio)): ?>
							<div class="single-format-content pf-audio">
								<?php echo htmlspecialchars_decode($d_audio); ?>
							</div>
						<?php endif;
						break;
					default :
						break;
				}
			endif;
		}
	endif;

	/*theme tags*/
	if(!function_exists('minera_blog_tags')):
		function minera_blog_tags(){
			if(has_tag()): ?>
				<div class="tagcloud" itemprop="keywords"><?php echo the_tags($before = esc_html__('Tags: ', 'minera'), $sep = ', ', $after = ''); ?></div>
			<?php endif;
		}
	endif;

	/*support structured data - SEO optimize*/
	if(!function_exists('minera_structured_data')):
		function minera_structured_data(){ ?>
			<div class="screen-reader-text">
				<?php /*heading*/ ?>
				<h2 itemprop="headline"><?php echo get_the_title(); ?></h2>
				<?php /*thumbnail*/ ?>
				<?php if(is_single()):
					global $post;
					$thumbnail = get_the_post_thumbnail_url($post->ID, 'thumbnail');

					if(!empty($thumbnail)){
						$img_id  = get_post_thumbnail_id($post->ID);
						$img_alt = minera_img_alt($img_id, 'Blog thumbnail'); ?>
						<span itemprop="image" itemscope itemtype="http://schema.org/ImageObject">
							<img src="<?php echo esc_url($thumbnail); ?>" alt="<?php echo esc_attr($img_alt); ?>">
							<meta itemprop="url" content="<?php echo esc_url($thumbnail); ?>" />
							<meta itemprop="width" content="840" />
							<meta itemprop="height" content="360" />
						</span>
					<?php }else{ ?>
						<span itemprop="image" itemscope itemtype="http://schema.org/ImageObject">
							<img src="<?php echo get_template_directory_uri() . '/images/thumbnail-default.jpg'; ?>" alt="<?php esc_attr_e('Thumbnail', 'minera'); ?>">
							<meta itemprop="url" content="<?php echo get_template_directory_uri() . '/images/thumbnail-default.jpg'; ?>" />
							<meta itemprop="width" content="100" />
							<meta itemprop="height" content="90" />
						</span>
					<?php } ?>
				<?php endif; ?>
				<?php /*publisher*/ ?>
				<div itemprop="publisher" itemscope="itemscope" itemtype="https://schema.org/Organization">
					<div itemprop="logo" itemscope="itemscope" itemtype="https://schema.org/ImageObject">
						<meta itemprop="url" content="<?php echo esc_url(home_url('/')); ?>" />
						<meta itemprop="width" content="100" />
						<meta itemprop="height" content="100" />
					</div>
					<meta itemprop="name" content="<?php the_author(); ?>" />
				</div>
				<?php /*date modified*/ ?>
				<span itemprop="dateModified">
					<time datetime="<?php echo esc_attr( get_the_modified_time( 'Y-m-d' ) ); ?>">
						<?php the_modified_date(); ?>
					</time>
				</span>
				<?php /*date published*/ ?>
				<span itemprop="datePublished" content="<?php echo get_the_time('c'); ?>"><?php echo get_the_time('c'); ?></span>
				<?php /*post categories*/ ?>
				<div itemprop="articleSection"><?php echo minera_blog_categories(); ?></div>
			</div>
		<?php }
	endif;

	/* header layout */
	if(!function_exists('minera_header_layout')){
		function minera_header_layout(){
			/*PAGE OPTIONS*/
			$pid = get_queried_object_id();
			$p_header_layout = (function_exists('fw_get_db_post_option')) ? fw_get_db_post_option($pid, 'page_header_layout') : 'default';

			/*CUSTOMIZER*/
			$c_header_layout = get_theme_mod('header_layout_cfg', 'layout-1');

			// Some issue with product category.
			if ( class_exists( 'woocommerce' ) && is_product_category() && isset( $p_header_layout['gadget'] ) ) {
				$p_header_layout['gadget'] = 'default';
			}

			if(isset($p_header_layout['gadget']) && $p_header_layout['gadget'] != 'default' ){
				switch($p_header_layout['gadget']){
					case 'layout-1' :
						get_template_part('page-templates/header', 'layout-1');
						break;
					case 'layout-2' :
						get_template_part('page-templates/header', 'layout-2');
						break;
					case 'layout-3' :
						get_template_part('page-templates/header', 'layout-3');
						break;
					case 'layout-4' :
						get_template_part('page-templates/header', 'layout-4');
						break;
					case 'layout-5' :
						get_template_part('page-templates/header', 'layout-5');
						break;
					case 'layout-6' :
						get_template_part('page-templates/header', 'layout-6');
						break;
				}
			}else{
				switch($c_header_layout){
					case 'layout-1' :
						get_template_part('page-templates/header', 'layout-1');
						break;
					case 'layout-2' :
						get_template_part('page-templates/header', 'layout-2');
						break;
					case 'layout-3' :
						get_template_part('page-templates/header', 'layout-3');
						break;
					case 'layout-4' :
						get_template_part('page-templates/header', 'layout-4');
						break;
					case 'layout-5' :
						get_template_part('page-templates/header', 'layout-5');
						break;
					case 'layout-6' :
						get_template_part('page-templates/header', 'layout-6');
						break;
					default :
						get_template_part('page-templates/header', 'layout-1');
						break;
				}
			}
		}
	}

	/*check header layout*/
	if(!function_exists('minera_check_header_layout')){
		function minera_check_header_layout(){
			/*PAGE OPTIONS*/
			$pid = get_queried_object_id();
			$p_header_layout = (function_exists('fw_get_db_post_option')) ? fw_get_db_post_option($pid, 'page_header_layout') : 'default';

			/*CUSTOMIZER*/
			$c_header_layout = get_theme_mod('header_layout_cfg', 'layout-1');

			/*variable*/
			$output = '';

			if(isset($p_header_layout['gadget']) && $p_header_layout['gadget'] != 'default' ){
				switch($p_header_layout['gadget']){
					case 'layout-1' :
						$output = 'layout-1';
						break;
					case 'layout-2' :
						$output = 'layout-2';
						break;
					case 'layout-3' :
						$output = 'layout-3';
						break;
					case 'layout-4' :
						$output = 'layout-4';
						break;
					case 'layout-5' :
						$output = 'layout-5';
						break;
					case 'layout-6' :
						$output = 'layout-6';
						break;
				}
			}else{
				switch($c_header_layout){
					case 'layout-1' :
						$output = 'layout-1';
						break;
					case 'layout-2' :
						$output = 'layout-2';
						break;
					case 'layout-3' :
						$output = 'layout-3';
						break;
					case 'layout-4' :
						$output = 'layout-4';
						break;
					case 'layout-5' :
						$output = 'layout-5';
						break;
					case 'layout-6' :
						$output = 'layout-6';
						break;
					default :
						$output = 'layout-1';
						break;
				}
			}
			return $output;
		}
	}

	/*header layout 6*/
	if(!function_exists('minera_header_layout_six')){
		function minera_header_layout_six($start = true){
			/*PAGE OPTIONS*/
			$pid = get_queried_object_id();
			$p_layout = (function_exists('fw_get_db_post_option')) ? fw_get_db_post_option($pid, 'page_header_layout') : 'default';

			/*CUSTOMIZER*/
			$c_layout = get_theme_mod('header_layout_cfg', 'layout-1');

			$final_layout = $c_layout;

			if(isset($p_layout['gadget']) && $p_layout['gadget'] != 'default' ){
				$final_layout = $p_layout['gadget'];
			}

			if($final_layout == 'layout-6'){
				if($start == true){ ?>
					<div id="mainview" class="layout-content flw">
				<?php }else{ ?>
					</div>
				<?php }
			}
		}
	}

	/*page content boxed layout*/
	if(!function_exists('minera_page_content_boxed')){
		function minera_page_content_boxed($start = true){
			$pid = get_queried_object_id();
			if($pid == 0) return;

			$p_layout = (function_exists('fw_get_db_post_option')) ? fw_get_db_post_option($pid, 'content_layout', 'default') : 'default';

			switch($p_layout){
				case 'boxed':
					/*boxed layout 1*/
					if($start == true){ ?>
						<div class="page-content-boxed">
					<?php }else{ ?>
						</div>
					<?php }
					break;
				case 'boxed-50':
					/*boxed layout 2*/
					if($start == true){ ?>
						<div class="page-content-boxed-padding">
					<?php }else{ ?>
						</div>
					<?php }
					break;
			}
		}
	}

	/*header search form*/
	if(!function_exists('minera_search_form')){
		function minera_search_form(){ ?>
			<div id="search-form-content">
				<form class="theme-search-form" action="<?php echo esc_url(home_url('/')); ?>" method="get" role="search">
					<input id="ht-search-field" type="text" name="s" required>
					<span class="ht-search-info"><?php esc_html_e('Hit enter to search or ESC to close', 'minera'); ?></span>
					<?php
					$product_only = get_theme_mod( 'product_search', false );
					if ( $product_only ) {
					?>
					<input type="hidden" name="post_type" value="product">
					<?php } ?>
				</form>
			</div>
		<?php }
	}

		/*mobile version*/
		if(!function_exists('minera_search_form_mobile')){
			function minera_search_form_mobile(){ ?>
				<form class="mobile-search-form" action="<?php echo esc_url(home_url('/')); ?>" method="get" role="search">
					<input type="text" name="s" placeholder="<?php esc_attr_e('Search...', 'minera'); ?>" required>
					<?php
					$product_only = get_theme_mod( 'product_search', false );
					if ( $product_only ) {
					?>
					<input type="hidden" name="post_type" value="product">
					<?php } ?>
					<button type="submit" class="ht-ico-search"></button>
				</form>
			<?php }
		}

	/*logo*/
	if(!function_exists('minera_logo_image')){
		function minera_logo_image(){
			$pid = get_queried_object_id();
			$p_lg = function_exists('fw_get_db_post_option') ? fw_get_db_post_option($pid, 'p_lg') : '';

			$c_lg = get_theme_mod('logo_img', '');
			$retina_lg = get_option('logo_retina');

			$lg_img = get_template_directory_uri() . '/images/lg.png';

			/*logo image*/
			if(!empty($c_lg)){
				$lg_img = $c_lg;
			}

			/*retina logo support*/
			if(!empty($retina_lg)){
				$lg_img = $retina_lg;
			}

			$tag = 'figure';
			$tag_child = 'figcaption';
			if( is_front_page() ){
				$tag = 'h1';
				$tag_child = 'span';
			}


			if(isset($p_lg['gadget']) && $p_lg['gadget'] == 'custom'){
				$lg_img = ! empty( $p_lg['custom']['lg_data']['url'] ) ? $p_lg['custom']['lg_data']['url'] : get_template_directory_uri() . '/images/lg.png';
			?>
				<<?php echo esc_attr($tag); ?> itemscope itemtype="http://schema.org/Organization" class="theme-logo">
					<a class="lg" href="<?php echo esc_url(home_url('/')); ?>" itemprop="url">
						<img src="<?php echo esc_url($lg_img); ?>"
							alt="<?php esc_attr_e('Logo image', 'minera'); ?>"
							itemprop="logo" >
					</a>
					<<?php echo esc_attr($tag_child); ?> class="screen-reader-text"><?php echo esc_attr( bloginfo( 'name' ) ); ?></<?php echo esc_attr($tag_child); ?>>
				</<?php echo esc_attr($tag); ?>>
			<?php }else{ ?>
				<<?php echo esc_attr($tag); ?> itemscope itemtype="http://schema.org/Organization" class="theme-logo">
					<a class="lg" href="<?php echo esc_url(home_url("/")); ?>" itemprop="url">
						<img
							src="<?php echo esc_url($lg_img); ?>"
							alt="<?php esc_attr_e('Logo image', 'minera'); ?>"
							itemprop="logo" >
					</a>
					<<?php echo esc_attr($tag_child); ?> class="screen-reader-text"><?php echo esc_attr( bloginfo( 'name' ) ); ?></<?php echo esc_attr($tag_child); ?>>
				</<?php echo esc_attr($tag); ?>>
			<?php }
		}
	}

	/*edit location*/
	if(!function_exists('minera_edit_location')){
		function minera_edit_location($id = ''){
			$option = $id.'_edit_location';
			if(is_customize_preview()):
				echo '<div id="' . esc_attr($id) . '-edit-location">';
					if ( class_exists( 'Kirki' ) ){echo Kirki::get_option($option);}
				echo '</div>';
			endif;
		}
	}

	/*extract footer layout css*/
	add_action('wp_enqueue_scripts', 'minera_extract_footer_css');
	if(!function_exists('minera_extract_footer_css')){
		function minera_extract_footer_css(){
			/*page option*/
			$pid = get_queried_object_id();

			/*customize option*/
			$c_footer = get_theme_mod('c_footer_layout', 'default');
			$footer_id = $c_footer;

			$p_footer = function_exists('fw_get_db_post_option') ? fw_get_db_post_option($pid, 'footer_layout') : 'default';

			if(!empty($p_footer) && $p_footer != 'default'){
				$footer_id = $p_footer;
			}
			if($footer_id != 'default' && $footer_id != 'disable' && class_exists( 'WPBakeryVisualComposerAbstract' )){
				$content = get_post($footer_id)->post_content;
				$content_css = visual_composer()->parseShortcodesCustomCss( $content );
				if ( ! empty( $content_css ) ) { ?><style type="text/css"><?php echo strip_tags( $content_css ); ?></style>
				<?php }
			}
		}
	}

	/*default font style when `kirki` not active*/
	add_action('wp_enqueue_scripts', 'minera_default_font_style');
	function minera_default_font_style() {
		$default = get_theme_mod( 'typo_body', array('font-family' => 'Poppins'));
		if(!class_exists('Kirki')){
			echo '<style type="text/css">body, p, input, select, textarea, button{font-family: ' . $default['font-family'] . ', sans-serif!important}</style>';
		}
	}

	/*add custom inline scripts*/
	add_action( 'wp_enqueue_scripts', 'minera_add_inline_script' );
	if(!function_exists('minera_add_inline_script')):
		function minera_add_inline_script($scripts) {
			wp_add_inline_script( 'minera-theme-script', $scripts, 'before' );
		}
	endif;

	/*sticky menu*/
	if(!function_exists('minera_sticky_menu')):
		function minera_sticky_menu(){
			if(minera_check_header_layout() == 'layout-6') return;

			$sticky = get_theme_mod('sticky', false);

			if($sticky){ ?>
				<div id="theme-sticky-menu" class="theme-header-layout" itemscope itemtype="http://schema.org/WPHeader">
					<?php minera_edit_location('sticky_menu');/*header edit location*/ ?>
					<div class="header-box">
						<div class="container">
							<?php minera_logo_image();/*logo*/ ?>
							<div class="wrap-menu" itemscope itemtype="http://schema.org/SiteNavigationElement">
								<span class="screen-reader-text"><?php esc_html_e( 'Primary Menu', 'minera' ); ?></span>
								<?php if(has_nav_menu('primary')):
									wp_nav_menu( array( 'theme_location' => 'primary', 'menu_class' => 'theme-primary-menu', 'container' => '' ) );
								else: ?>
									<a class="add-menu" href="<?php echo esc_url( get_admin_url() . 'nav-menus.php' ); ?>"><?php esc_html_e( 'Add Menu', 'minera' ); ?></a>
								<?php endif; ?>
							</div>
							<div class="header-action hd1-action">
								<?php do_action( 'minera_sticky_header_action_before' ); ?>
								<button class="ht-ico-search theme-search-btn" id="sticky-search-btn"></button>
								<?php minera_account(); ?>
								<?php minera_shopping_cart();/*shopping cart*/ ?>
								<?php do_action( 'minera_sticky_header_action_after' ); ?>
							</div>
						</div>
					</div>
				</div>
			<?php
				wp_enqueue_script( 'minera-headroom-stick-menu', get_template_directory_uri() . '/js/headroom.min.js', array('jquery'), false, true );
				wp_add_inline_script(
					'minera-headroom-stick-menu',
					'var width = matchMedia("(min-width:992px)"),
						el = document.getElementById("theme-sticky-menu"),
						options = {
							offset: 200,
							classes : {
								initial : "header-sticky",
								pinned : "menu-scrolling-up",
								unpinned : "menu-scrolling-down",
								top : "menu-top",
								notTop : "menu-not-top",
								bottom : "menu-bottom",
								notBottom : "menu-not-bottom"
							}
						},
						headroom = new Headroom(el, options);

					function minera_sticky_menu(data) {
						if(data.matches){
							headroom.init();
						}else{
							headroom.destroy();
						}
					}

					minera_sticky_menu(width);
					width.addListener(minera_sticky_menu);',
					'after'
				);
			}
		}
	endif;

	// Sticky mobile menu overlay.
	if ( ! function_exists( 'minera_sticky_mobile_menu_over_lay' ) ) {
		function minera_sticky_mobile_menu_over_lay() {
			if ( false == get_theme_mod( 'sticky', false ) && false == get_theme_mod( 'sticky_mobile', false ) ) {
				return;
			}

			echo '<span class="sticky-mobile-menu-overlay"></span>';
		}
	}
}

/*THEME CSS INLINE ************************************************************/
function minera_css_inline() {
	if(!function_exists('FW')) return;

	$css = '';
	/*page id*/
	$id = get_queried_object_id();
	$page_id = '.page-id-' . $id;

	/*DEFAULT FONT STYLE*/
		if(class_exists('Kirki')){
			$default = get_theme_mod( 'typo_body', array('font-family' => 'Poppins', 'font-size' => '14px'));
			$css .= 'input, select, textarea, button, .header-layout-3 .theme-search-btn:after, .header-layout-5 .theme-search-btn:after, .p-action .p-tooltip{font-family:' . $default['font-family'] . '}';
			$css .= 'input, select, textarea, button{font-size:' . $default['font-size'] . '}';

			/*start theme*/
			$css .= '@media (min-width: 992px){';
			$css .= '.header-layout-1 .header-box{position: absolute}';
			$css .= '}';
		}
	/*MENU BACKGROUNG IMAGE=========================*/
		$primary_menu = get_nav_menu_locations();/*get primary menu id*/
		if(isset($primary_menu['primary'])){
			$menu = wp_get_nav_menu_items($primary_menu['primary']);/*get list menu item id*/
			if(!empty($menu)):/*get option of menu item*/
				foreach($menu as $key){
					$options = function_exists('fw_ext_mega_menu_get_db_item_option') ? fw_ext_mega_menu_get_db_item_option($key->ID, 'row') : '';
					if(!empty($options['bg'])){
						$css .= '.menu-item-'.$key->ID.' .mega-menu-row{background-image: url(' . $options['bg']['url'] . ');}';
					}
				}
			endif;
		}
	/*CONTENT ======================================*/
		$content_bg = fw_get_db_post_option($id, 'content_bg');
		/*background color*/
		if($content_bg != '#ffffff'){
			$css .= $page_id . ' #theme-container{background-color: '. $content_bg .'}';
		}
	/*PRODUCT CATEGORY SIDEBAR BACKGROUND===========*/
		if(class_exists('WooCommerce') && is_product_category()){
			$id = get_queried_object()->term_id;
			$tax_name = get_queried_object()->taxonomy;

			$p_sidebar_position = fw_get_db_term_option($id, $tax_name, 'sidebar_data');

			if(isset($p_sidebar_position['gadget'])){
				if($p_sidebar_position['gadget'] == 'left'){
					$sidebar_left_bg = $p_sidebar_position['left']['sidebar_bg'];
					$css .= '.term-' . $id . ' .shop-archive-sidebar{background-color:' . $sidebar_left_bg . '}';
				}
				if($p_sidebar_position['gadget'] == 'right'){
					$sidebar_left_bg = $p_sidebar_position['right']['sidebar_bg'];
					$css .= '.term-' . $id . ' .shop-archive-sidebar{background-color:' . $sidebar_left_bg . '}';
				}
			}
			/* page header background image in product category, priority highest */
			$header_image = fw_get_db_term_option($id, $tax_name, 'category_header');
			if(isset($header_image['gadget']) && $header_image['gadget'] == 'custom'){
				$css .= '.archive.shop-archive.term-' . $id . ' .theme-breadcrumb{background-image:url(' . $header_image['custom']['header_bg']['url'] . ') !important}';
			}

		}
	/*HEADER LAYOUT=================================*/
		$p_header_layout = fw_get_db_post_option($id, 'page_header_layout');
		$css .= '@media (min-width: 992px){';

		if($p_header_layout['gadget'] != 'default' ){
			switch($p_header_layout['gadget']){
				/*LAYOUT 1*/
				case 'layout-1' :
					$header = $p_header_layout['layout-1']['custom'];
					if(isset($header['gadget']) && $header['gadget'] == 'yes'){
						/*wider*/
						if(isset($header['yes']['wider']) && $header['yes']['wider'] == 'yes'){
							$css .= '@media (min-width: 1680px){';
							$css .= $page_id . ' .header-layout-1 .header-box .container{width: 1680px; padding-left: 0; padding-right: 0}';
							$css .= $page_id . ' .header-layout-1 .theme-primary-menu .mega-menu-row.mega-standard {width: 1680px; left: -webkit-calc((100% - 1170px) / 2); left: calc((100% - 1680px) / 2)}';
							$css .= '}';
						}
						/*background color*/
						if(isset($header['yes']['background_color']) && !empty($header['yes']['background_color'])){
							$css .= $page_id . ' .header-layout-1 .header-box{background-color: '. $header['yes']['background_color'] .'}';
						}
						/*bottom color*/
						if(isset($header['yes']['border_bottom_color']) && !empty($header['yes']['border_bottom_color'])){
							$css .= $page_id . ' .header-layout-1 .header-box{border-bottom-color: '. $header['yes']['border_bottom_color'] .'}';
						}
					}
					break;
				/*LAYOUT 2*/
				case 'layout-2' :
					$header = $p_header_layout['layout-2']['custom'];
					if(isset($header['gadget']) && $header['gadget'] == 'yes'){
						/*background color*/
						if(isset($header['yes']['background_color']) && !empty($header['yes']['background_color'])){
							$css .= $page_id . ' .header-layout-2 .header-box{background-color: '. $header['yes']['background_color'] .'}';
						}

						/*overlay*/
						if(isset($header['yes']['overlap'])){
							if($header['yes']['overlap'] == 'yes'){
								$css .= $page_id . ' .header-layout-2 .header-box{position: absolute; left: 0}';
							}else{
								$css .= $page_id . ' .header-layout-2 .header-box{position: relative; left: initial}';
							}
						}
						/*wider*/
						if(isset($header['yes']['wider']) && $header['yes']['wider'] == 'yes'){
							$css .= '@media (min-width: 1680px){';
							$css .= $page_id . ' .header-layout-2 .header-box .container{width: 1680px; padding-left: 30px; padding-right: 30px}';
							$css .= $page_id . ' .header-layout-2 .theme-primary-menu .mega-menu-row.mega-standard {width: 1680px; left: -webkit-calc((100% - 1170px) / 2); left: calc((100% - 1680px) / 2)}';
							$css .= '}';
						}
					}
					break;
				/*LAYOUT 3*/
				case 'layout-3' :
					break;
				/*LAYOUT 4*/
				case 'layout-4' :
					$header = $p_header_layout['layout-4']['custom'];
					if(isset($header['gadget']) && $header['gadget'] == 'yes'){
						/*background color*/
						$css .= $page_id . ' .header-layout-4 .header-box{background-color: '. $header['yes']['bg_color'] .'}';
						/*color 1*/
						$css .= $page_id . ' .header-layout-4 .shopping-cart-icon{color: '. $header['yes']['icon_color_1'] .'}';
						$css .= $page_id . ' .header-layout-4 .theme-search-btn{color: '. $header['yes']['icon_color_1'] .'}';
						$css .= $page_id . ' .header-layout-4 .theme-shopping-cart .counter-cart{background-color: '. $header['yes']['icon_color_1'] .'}';
						$css .= $page_id . ' .header-layout-4 #sidebar-menu-btn{background-color: '. $header['yes']['icon_color_1'] .'}';
						/*color 2*/
						$css .= $page_id . ' .header-layout-4 .theme-shopping-cart .counter-cart{color: '. $header['yes']['icon_color_2'] .'}';
						$css .= $page_id . ' .header-layout-4 #sidebar-menu-btn span, '. $page_id . ' .header-layout-4 #sidebar-menu-btn span:before, '. $page_id . ' .header-layout-4 #sidebar-menu-btn span:after{background-color: '. $header['yes']['icon_color_2'] .'}';
						/*wider*/
						if(isset($header['yes']['wider']) && $header['yes']['wider'] == 'yes'){
							$css .= '@media (min-width: 1680px){';
							$css .= $page_id . ' .header-layout-4 .header-box .container{width: 1680px; padding-left: 0; padding-right: 0}';
							$css .= $page_id . ' .header-layout-4 .theme-primary-menu .mega-menu-row.mega-standard {width: 1680px; left: -webkit-calc((100% - 1170px) / 2); left: calc((100% - 1680px) / 2)}';
							$css .= '}';
						}
					}
					break;
				/*LAYOUT 5*/
				case 'layout-5' :
					break;
				/*LAYOUT 6*/
				case 'layout-6' :
					break;
			}
		}
		$css .= '}';
	/*SINGLE PRODUCT*/
		$p_bread = (function_exists('fw_get_db_post_option')) ? fw_get_db_post_option($id, 'p_bread_bg') : '';
		if(is_singular( 'product' )){
			$css .= '@media (min-width: 992px){';
			$css .= '.single.single-product .bread-spacing-top, .single.single-product .bread-spacing-bot{height: 40px}';
			$css .= '.has-header-overlay.single.single-product .bread-spacing-top{height: 155px}';
			$css .= '}';
			$css .= '.single.single-product.shop-single-not-sidebar .theme-breadcrumb{margin-bottom: 0px}';
		}
		$position = minera_get_sidebar_position();

		if ( '' != $p_bread && 'full' == $position ) {
			$css .= '.postid-' . $id . '.shop-single-not-sidebar .theme-breadcrumb, .postid-' . $id . '.shop-single-not-sidebar .w-data-view{background-color: '. $p_bread .'}';
		}

	wp_add_inline_style( 'minera-magic-style', $css );
}
add_action( 'wp_enqueue_scripts', 'minera_css_inline', 1111 );


/* WOOCOMMERCE ACTION - FILTER
******************************************************************************************************/

// Remove default flash sale.
remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10 );

/*MODIFY woocommerce_before_shop_loop_item_title content-product.php*/
remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10 );
add_action( 'woocommerce_before_shop_loop_item_title', 'minera_modify_shop_item_title' );
if( !function_exists ('minera_modify_shop_item_title') ){
	function minera_modify_shop_item_title() {
		global $product, $woocommerce;

		/*product id*/
		$pid           = $product->get_id();

		/*image*/
		$img_id        = get_post_thumbnail_id( $pid );
		$img_src       = wp_get_attachment_image_src( $img_id, 'shop_catalog' );
		$origin_src    = $img_src;

		// Get product image single size.
		$img_size      = wc_get_image_size( 'shop_catalog' );

		if ( empty( $img_id ) ) {
			$img_src[0]    = woocommerce_placeholder_img_src();
			$img_src[1]    = $img_size['width'];
			$img_src[2]    = ! empty( $img_size['height'] ) ? $img_size['height'] : $img_size['width'];
			$origin_src[0] = $img_src[0];
		}

		$img_alt       = minera_img_alt( $img_id, esc_html__( 'Product image', 'minera' ) );

		/*add to Cart url*/
		$atc_url       = $product->add_to_cart_url();

		/*sale*/
		$sale          = $product->is_on_sale();
		$sale_price    = $product->get_sale_price();
		$regular_price = $product->get_regular_price();

		/*product type*/
		$variation     = $product->is_type( 'variable' );
		$external      = $product->is_type( 'external' );
		$simple        = $product->is_type( 'simple' );

		/*get hover img src*/
		$gallery_ids   = $product->get_gallery_image_ids();
		$hover_src     = '';
		if( isset( $gallery_ids[0] ) && !empty( $gallery_ids[0] ) ){
			$hover_src = wp_get_attachment_image_src( $gallery_ids[0], 'woocommerce_thumbnail' );
		}

		do_action( 'minera_loop_flash_sale' );
		?>

		<?php if( ! $product->is_in_stock() ): /*add sold out label*/ ?>
			<span class="p-sold-out"><?php esc_html_e( 'Sold Out', 'minera' ); ?></span>
		<?php endif; ?>

		<?php /*icon action: add-to-cat, quickview, add-to-wish-list*/ ?>
		<div class="p-action">
			<?php /*add to wishlist button*/ ?>
			<?php echo class_exists( 'YITH_WCWL') ? do_shortcode( '[yith_wcwl_add_to_wishlist product_id="'.$pid.'"]' ) : ''; ?>

			<?php /*quick view button*/ ?>
			<a href="<?php echo get_permalink( $pid ); ?>" data-id="<?php echo esc_attr( $pid ); ?>" class="quick-view-btn" aria-label="<?php esc_attr_e( 'Show in Quickview', 'minera' ); ?>">
				<span class="p-tooltip"><?php esc_html_e( 'Show in Quickview', 'minera' ); ?></span>
			</a>

			<?php /*add to Cart button*/ ?>
			<span class="p-box-atc">
				<?php if( $variation ): ?>
					<a href="<?php echo get_permalink( $pid ); ?>" class="select-option-btn ht-ico-cart" aria-label="<?php esc_attr_e( 'Select Options', 'minera' ); ?>">
						<span class="p-tooltip"><?php esc_html_e( 'Select Options', 'minera' ); ?></span>
					</a>
				<?php elseif( $external ): ?>
					<a href="<?php echo esc_url( $product->get_product_url() ); ?>" class="select-option-btn ht-ico-cart" aria-label="<?php esc_attr_e( 'Goto to product', 'minera' ); ?>">
						<span class="p-tooltip"><?php esc_html_e( 'Goto to product', 'minera' ); ?></span>
					</a>
				<?php else: ?>
					<a href="<?php echo esc_url( $atc_url ); ?>" data-quantity="1" data-product_id="<?php echo esc_attr( $pid ); ?>" class="add_to_cart_button ht-ico-cart <?php echo minera_ajax_act_opt(); ?>" aria-label="<?php esc_attr_e( 'Add to Cart', 'minera' ); ?>">
						<span class="p-tooltip"><?php esc_html_e( 'Add to Cart', 'minera' ); ?></span>
					</a>
				<?php endif; ?>
			</span>
		</div>

		<?php /*product image*/ ?>
		<a href="<?php echo get_permalink( $pid ); ?>" class="p-image" aria-label="<?php esc_attr_e( 'Product image', 'minera' ); ?>" data-ori_src="<?php echo esc_attr( $origin_src[0] ); ?>">
			<img src="<?php echo esc_url( $img_src[0] ); ?>" alt="<?php echo esc_attr( $img_alt ); ?>">
			<?php if( ! empty( $hover_src ) ): ?>
				<span class="p-img-hover" style="background-image: url(<?php echo esc_url( $hover_src[0] ); ?>)"></span>
			<?php endif; ?>
		</a>
	<?php
	}

}


if ( ! function_exists( 'minera_flash_sale' ) ) {
	function minera_flash_sale() {
		global $product;

		/*sale*/
		$sale          = $product->is_on_sale();
		$sale_price    = $product->get_sale_price();
		$regular_price = $product->get_regular_price();

		if ( ! $sale ) {
			return;
		}

		/*product type*/
		$simple        = $product->is_type( 'simple' );
		?>
		<span class="onsale">
			<?php
				if( $simple ){
					$final_price = ( ( $regular_price - $sale_price ) / $regular_price) * 100;
					echo '-' . round( $final_price ) . '%';
				}else{
					esc_html_e( 'Sale!', 'minera' );
				}
			?>
		</span>
		<?php
	}
}

add_action( 'minera_loop_flash_sale', 'minera_flash_sale', 10 );
add_action( 'minera_single_flash_sale', 'minera_flash_sale', 10 );


// Get current page id.
if ( ! function_exists( 'minera_get_page_id' ) ) {
	/**
	 * Get page id
	 *
	 * @return int $page_id Page id
	 */
	function minera_get_page_id() {
		$page_id = get_queried_object_id();

		if ( class_exists( 'woocommerce' ) && is_shop() ) {
			$page_id = get_option( 'woocommerce_shop_page_id' );
		}

		return $page_id;
	}
}

// Get registered sidebar.
add_action( 'init', 'minera_get_sidebars_registered', 999 );
function minera_get_sidebars_registered() {
	$sidebars = array();
	if ( isset( $GLOBALS['wp_registered_sidebars'] ) ) {
		$sidebars = $GLOBALS['wp_registered_sidebars'];
	}

	$sidebars_choices = array();
	foreach ( $sidebars as $sidebar ) {
		$sidebars_choices[ $sidebar['id'] ] = $sidebar['name'];
	}

	if ( ! class_exists( 'Kirki' ) || empty( $sidebars_choices ) ) {
		return;
	}

	Minera_Kirki::add_field( 'minera', array(
		'type'            => 'select',
		'settings'        => 'shop_page_sidebar_id',
		'label'           => esc_attr__( 'Sidebars Select', 'minera' ),
		'section'         => 'shop',
		'default'         => 'shop-widget',
		'choices'         => $sidebars_choices,
		'active_callback' => array(
			array(
				'setting'  => 'c_shop_sidebar',
				'operator' => '!=',
				'value'    => 'full'
	        )
		),
	) );

	Minera_Kirki::add_field( 'minera', array(
		'type'            => 'select',
		'settings'        => 'shop_single_sidebar_id',
		'label'           => esc_attr__( 'Sidebars Select', 'minera' ),
		'section'         => 'single_product',
		'default'         => 'shop-widget',
		'choices'         => $sidebars_choices,
		'active_callback' => array(
			array(
				'setting'  => 'shop_single_sidebar',
				'operator' => '!=',
				'value'    => 'full'
	        )
		),
	) );
}

// Get sidebar position.
if ( ! function_exists( 'minera_get_sidebar_position' ) ) {
	function minera_get_sidebar_position() {
		$c_sidebar = is_singular( 'product' ) ? get_theme_mod( 'shop_single_sidebar', 'full' ) : get_theme_mod( 'c_shop_sidebar', 'full' );

		$p_sidebar      = function_exists( 'fw_ext_sidebars_get_current_position' ) ? fw_ext_sidebars_get_current_position() : 'default';
		$sidebar_option = function_exists( 'fw_get_db_post_option' ) ? fw_get_db_post_option( minera_get_page_id(), 'sidebar' ) : array();

		$position       = isset( $p_sidebar ) && 'default' != $p_sidebar && ! empty( $sidebar_option ) ? $p_sidebar : $c_sidebar;

		return $position;
	}
}

// Get sidebar id.
if ( ! function_exists( 'minera_get_sidebar_id' ) ) {
	function minera_get_sidebar_id() {
		$id               = 'shop-widget';
		$c_shop_sidebar   = get_theme_mod( 'c_shop_sidebar', 'full' );
		$c_single_sidebar = get_theme_mod( 'shop_single_sidebar', 'full' );

		if ( is_singular( 'product' ) ) {
			if ( 'full' != $c_single_sidebar ) {
				$id = get_theme_mod( 'shop_single_sidebar_id', 'shop-widget' );
			}
		} else {
			if ( 'full' != $c_shop_sidebar ) {
				$id = get_theme_mod( 'shop_page_sidebar_id', 'shop-widget' );
			}
		}

		$p_sidebar      = function_exists( 'fw_ext_sidebars_get_current_position' ) ? fw_ext_sidebars_get_current_position() : 'default';
		$sidebar_option = function_exists( 'fw_get_db_post_option' ) ? fw_get_db_post_option( 'minera_get_page_id', 'sidebar' ) : array();

		if ( isset( $p_sidebar ) && 'default' != $p_sidebar && ! empty( $sidebar_option ) ){
			foreach ( $sidebar_option['sidebars'] as $k => $v ) {
				$id = $v;
			}
		}

		return $id;
	}
}

// Remove admin.css file on frontend.
add_action( 'wp_enqueue_scripts', 'minera_remove_wc_admin_style_on_frontend' );
function minera_remove_wc_admin_style_on_frontend() {
	if ( ! is_admin() ) {
		wp_deregister_style( 'woocommerce_admin_styles' );
		wp_dequeue_style( 'woocommerce_admin_styles' );
	}
}