<?php
/**
 * Woocommerce template functions
 *
 * @package minera
 */

if ( ! function_exists( 'minera_add_product_single_info' ) ) {
	function minera_add_product_single_info() {
		global $product;

		$pid          = $product->get_id();
		$stock_mng    = get_post_meta( get_the_ID(), '_manage_stock', true );
		$stock_qty    = $product->get_stock_quantity();
		$qty_hidden   = ( 'yes' == $stock_mng && $stock_qty < 2 ) ? 'hidden' : '';
		$in_cart_qty  = minera_product_in_cart( $pid ) ? minera_product_qty_in_cart( $pid ) : '0';
		$not_enough   = '';
		$out_of_stock = '';

		if ( 'yes' == $stock_mng ) {
			$not_enough   = esc_html__( 'You cannot add that amount of this product to the cart because there is not enough stock.', 'minera' );
			$out_of_stock = sprintf( esc_html__( 'You cannot add that amount to the cart - we have %1$s in stock and you already have %1$s in your cart', 'minera' ), $stock_qty );
		}
		?>
		<input
			type="hidden"
			value="<?php echo esc_attr( $in_cart_qty ); ?>"
			data-stock_manager="<?php echo esc_attr( $stock_mng ); ?>"
			data-out_of_stock="<?php echo esc_attr( $out_of_stock ); ?>"
			data-not_enough="<?php echo esc_attr( $not_enough ); ?>"
			data-stock_qty="<?php echo esc_attr( $stock_qty ); ?>" >
		<?php
	}
}
if ( ! function_exists( 'minera_get_variation_gallery' ) ) {
	/**
	 * Get variation gallery
	 *
	 * @param object $product The product.
	 */
	function minera_get_variation_gallery( $product ) {
		$images = array();

		if ( ! $product->is_type( 'variable' ) ) {
			return $images;
		}

		$variations = array_values( $product->get_available_variations() );

		$images = array();
		foreach ( $variations as $k ) {
			array_unshift( $k['variation_gallery_images'], array( 'variation_id' => $k['variation_id'] ) );
			array_push( $images, $k['variation_gallery_images'] );
		}

		return $images;
	}
}

if ( ! function_exists( 'minera_get_default_gallery' ) ) {
	/**
	 * Get variation gallery
	 *
	 * @param object $product The product.
	 */
	function minera_get_default_gallery( $product ) {
		$images                 = array();
		$product_id             = $product->get_id();
		$gallery_images         = $product->get_gallery_image_ids();
		$has_default_thumbnails = false;

		if ( ! empty( $gallery_images ) ) {
			$has_default_thumbnails = true;
		}

		if ( has_post_thumbnail( $product_id ) ) {
			array_unshift( $gallery_images, get_post_thumbnail_id( $product_id ) );
		}

		if ( ! empty( $gallery_images ) ) {
			foreach ( $gallery_images as $i => $image_id ) {
				$images[ $i ]                           = wc_get_product_attachment_props( $image_id );
				$images[ $i ]['image_id']               = $image_id;
				$images[ $i ]['has_default_thumbnails'] = $has_default_thumbnails;
			}
		}

		return $images;
	}
}

if ( ! function_exists( 'minera_global_for_vartiation_gallery' ) ) {
	/**
	 * Add global variation
	 *
	 * @param object $product The Product.
	 */
	function minera_global_for_vartiation_gallery( $product ) {

		// Minera Variation gallery.
		wp_localize_script(
			'product-image',
			'minera_variation_gallery',
			minera_get_variation_gallery( $product )
		);

		// Minera default gallery.
		wp_localize_script(
			'product-image',
			'minera_default_gallery',
			minera_get_default_gallery( $product )
		);
	}
}
