/**
 * Product variation
 *
 * @package woostify
 */

/* global woostify_woocommerce_variable_product_data */

'use strict';

/**
 * Variation product
 *
 * @param      string selector  The selector.
 * @param      string form      The form.
 */
function productVariation( selector, form ) {
	var gallery        = document.querySelector( selector ),
		variationsForm = form ? form : 'form.variations_form';
	if ( ! gallery || ! jQuery( variationsForm ).length ) {
		return;
	}

	var imageWrapper = gallery.querySelector( '.image-item' ),
		image        = imageWrapper ? imageWrapper.querySelector( 'img' ) : false,
		imageSrc     = image ? image.getAttribute( 'src' ) : '',
		imageSrcset  = image ? image.getAttribute( 'srcset' ) : '',

		// Product thumbnail.
		thumb    = gallery.querySelector( '.thumbnail-item' ),
		thumbImg = thumb ? thumb.querySelector( 'img' ) : false,
		thumbSrc = thumbImg ? thumbImg.getAttribute( 'src' ) : '';

	if ( ! jQuery( variationsForm ).length ) {
		return;
	}

	jQuery( document.body ).on(
		'found_variation',
		variationsForm,
		function( event, variation ) {
			// get image url form `variation`.
			var imgSrc  = variation.image.src,
				inStock = variation.is_in_stock;

			// Change image src image.
			if ( image ) {
				imageWrapper.classList.add( 'image-loading' );

				var img    = new Image();
				img.onload = function () {
					imageWrapper.classList.remove( 'image-loading' );
				}

				img.src = imgSrc;
				image.setAttribute( 'src', imgSrc );

				if ( imageSrcset ) {
					image.setAttribute( 'srcset', variation.image.srcset );
				}
			}

			// Change thumb src image.
			if ( thumbImg ) {
				thumbImg.setAttribute( 'src', variation.image.thumb_src );
			}

		}
	);

	// Reset variation.
	jQuery( '.reset_variations' ).on(
		'click',
		function( e ) {
			e.preventDefault();

			// Support Product meta widget.
			if ( productMetaSkuDefault ) {
				productMetaSku.innerHTML = productMetaSkuDefault;
			}

			if ( wpmGtinCodeWrapper ) {
				wpmGtinCodeWrapper.innerHTML = productMetaSkuDefault;
			}

			// Reset src image.
			if ( image ) {
				imageWrapper.classList.add( 'image-loading' );

				var resetImg    = new Image();
				resetImg.onload = function () {
					imageWrapper.classList.remove( 'image-loading' );
				}

				resetImg.src = imageSrc;
				image.setAttribute( 'src', imageSrc );

				if ( imageSrcset ) {
					image.setAttribute( 'srcset', imageSrcset );
				}
			}

			if ( thumbSrc ) {
				thumbImg.setAttribute( 'src', thumbSrc );
			}

			// Photoswipe + zoom.
			photoSwipe.setAttribute( 'href', photoSwipeSrc );

			// Zoom handle.
			if ( 'function' === typeof( easyZoomHandle ) ) {
				easyZoomHandle();
			}
		}
	);
}

document.addEventListener(
	'DOMContentLoaded',
	function() {
		productVariation( '.w-images-box' );
	}
);
