<?php
// @codingStandardsIgnoreStart
/**
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 3.6.0
 */

defined( 'ABSPATH' ) || exit;

global $product;

/*Ensure visibility*/
if ( empty( $product ) || ! $product->is_visible() ) {
    return;
}

/*product id*/
$pid       = $product->get_id();

/*price*/
$p_price   = $product->get_price_html();

/*description*/
$p_desc    = get_the_excerpt($pid);

/*add to Cart url*/
$atc_url   = $product->add_to_cart_url();

/*product type*/
$variation = $product->is_type( 'variable' );
$external  = $product->is_type( 'external' );

?>



<li <?php wc_product_class( 'p-col' ); ?>>
    <?php
        /**
         * Hook: woocommerce_before_shop_loop_item.
         *
         * @hooked woocommerce_template_loop_product_link_open - 10
         */
        do_action( 'woocommerce_before_shop_loop_item' );
    ?>
    <div class="p-head-cont">
        <div class="p-head">
            <?php do_action( 'woocommerce_before_shop_loop_item_title' ); ?>
        </div>
        <div class="p-content">
            <a class="p-title" href="<?php echo get_permalink($pid); ?>" aria-label="<?php esc_attr_e('Product title', 'minera'); ?>"><?php echo get_the_title($pid); ?></a>

            <?php do_action( 'minera_after_shop_loop_title' ); ?>

            <div class="price" aria-label="<?php esc_attr_e('Product price', 'minera'); ?>"><?php echo wp_kses_post($p_price); ?></div>

			<?php do_action( 'minera_after_shop_loop_price ' ); ?>

            <div class="p-attr">
                <?php minera_swatches_list();/*swatches color*/ ?>
            </div>
            <div class="p-desc" aria-label="<?php esc_attr_e('Product description', 'minera'); ?>"><?php echo wp_kses_post($p_desc); ?></div>
            <?php /*list style: add to Cart button*/ ?>
            <div class="atc-shop-list">
                <?php if( $variation ): ?>
                    <a href="<?php echo get_permalink($pid); ?>" class="atc-select-option-btn" aria-label="<?php esc_attr_e('Select Options', 'minera'); ?>"><?php esc_html_e('Select Options', 'minera'); ?></a>
                <?php elseif( $external ): ?>
                    <a href="<?php echo esc_url( $product->get_product_url() ); ?>" class="atc-select-option-btn" aria-label="<?php esc_attr_e( 'Goto to product', 'minera' ); ?>"><?php esc_html_e( 'Goto to product', 'minera' ); ?></a>
                <?php else: ?>
                    <a href="<?php echo esc_url($atc_url); ?>" data-quantity="1" data-product_id="<?php echo esc_attr($pid); ?>" class="add_to_cart_button <?php echo minera_ajax_act_opt(); ?>" aria-label="<?php esc_attr_e('Add to Cart', 'minera'); ?>"><?php esc_html_e('Add to Cart', 'minera'); ?></a>
                <?php endif; ?>
            </div>
        </div>
        <div class="p-attr">
            <?php minera_swatches_list();/*swatches color*/ ?>
        </div>
    </div>
    <?php
        /**
         * Hook: woocommerce_after_shop_loop_item.
         *
         * @hooked woocommerce_template_loop_product_link_close - 5
         * @hooked woocommerce_template_loop_add_to_cart - 10
         */
        do_action( 'woocommerce_after_shop_loop_item' );
    ?>
</li>