<?php // @codingStandardsIgnoreStart
/**
 * Single Product Image
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 3.5.1
 */

defined( 'ABSPATH' ) || exit;

global $post, $product;

/*gallery layout list*/
$c_shop_layout = get_theme_mod( 'c_shop_layout', 'horizontal' );
$type          = $c_shop_layout;

$p_shop_layout = function_exists( 'fw_get_db_post_option' ) ? fw_get_db_post_option( $post->ID, 'p_shop_layout' ) : 'default';
if ( isset( $p_shop_layout ) && 'default' != $p_shop_layout ) {
	$type = $p_shop_layout;
}

/*sale*/
$sale          = $product->is_on_sale();
$sale_price    = $product->get_sale_price();
$regular_price = $product->get_regular_price();

/*variation product*/
$variation     = $product->is_type( 'variable' );
$simple        = $product->is_type( 'simple' );

/*img id*/
$img_id        = get_post_thumbnail_id( $post->ID );

/*img alt*/
$img_alt       = minera_img_alt( $img_id, esc_html__( 'Product image', 'minera' ) );

/*img full size*/
$image         = wp_get_attachment_image_src( $img_id, 'full' );
/*img view on main carousel*/
$slide_img     = wp_get_attachment_image_src( $img_id, 'woocommerce_single' );

// Get product image single size.
$img_size      = wc_get_image_size( 'woocommerce_single' );

if ( ! has_post_thumbnail() ) {
	$image[0]     = woocommerce_placeholder_img_src();
	$image[1]     = $img_size['width'];
	$image[2]     = ! empty( $img_size['height'] ) ? $img_size['height'] : $img_size['width'];
	$slide_img[0] = $image[0];
}
/*img thumbnail*/
$slide_thumb   = 'list' != $type ? wp_get_attachment_image_src( $img_id, 'thumbnail' ) : wp_get_attachment_image_src( $img_id, 'full' );

/*gallery ids*/
$gallery_ids   = $product->get_gallery_image_ids();
?>

<div class="w-images-box w-layout-<?php echo 'list' != $type ? 'slider' : 'list'; ?>">
	<?php do_action( 'minera_single_flash_sale' ); ?>
	<?php do_action( 'minera_product_thumbnails' ); ?>

	<?php
	/*CREATE ATTRIBUTE*/
	$tag      = 'div';
	$class    = '';
	$attr     = '';
	$img_attr = '';
	$main_id  = '';

	if ( true == get_theme_mod( 'effect_off', true ) ) {
		if ( true == get_theme_mod( 'c_shop_lightbox', false ) ) {
			/*FOR LIGHTBOX OPTION*/
			$main_id  = 'product-lightbox';
			$tag      = 'a';
			$attr     = 'href="' . esc_url( $image[0] ) . '"';
			$img_attr = 'data-original-src-width="' . $image[1] . '" data-original-src-height="' . $image[2] . '"';
		} else {
			/*FOR EZ-ZOOM OPTION*/
			$attr  = 'data-zoom="' . esc_url( $image[0] ) . '"';
			$class = 'ez-zoom';
		}
	}

	$has_slider = ! empty( $gallery_ids ) ? 'has-wrapper-slider' : '';
	?>

	<div class="w-img-crs w-crs <?php echo esc_attr( $has_slider ); ?>" id="<?php echo esc_attr( $main_id ); ?>">
		<<?php echo esc_attr( $tag ); ?> <?php echo wp_kses_post( $attr ); ?> class="w-img-item <?php echo esc_attr( $class ); ?>">
			<img src="<?php echo esc_url( $slide_img[0] ); ?>" <?php echo wp_kses_post( $img_attr ); ?> alt="<?php echo esc_attr( $img_alt ); ?>">
		</<?php echo esc_attr( $tag ); ?>>
		<?php
		/*GET MAIN IMAGE SLIDE FROM GALLERY IMAGE*/
		if ( ! empty( $gallery_ids ) ) :
			foreach ( $gallery_ids as $key ) :
				$image_in_gallery = wp_get_attachment_image_src( $key, 'full' );/*full image*/
				if ( ! empty( $image_in_gallery ) ) :
					$slide_in_gallery = wp_get_attachment_image_src( $key, 'woocommerce_single' );/*thumbnail image*/
					$img_alt          = minera_img_alt( $key, 'Product image thumbnail' );

					if ( true == get_theme_mod( 'c_shop_lightbox', false ) ) {
						/*FOR LIGHTBOX OPTION*/
						$attr     = 'href="' . esc_url( $image_in_gallery[0] ) . '"';
						$img_attr = 'data-original-src-width="' . $image_in_gallery[1] . '" data-original-src-height="' . $image_in_gallery[2] . '"';
					} else {
						/*FOR EZ-ZOOM OPTION*/
						$attr = 'data-zoom="' . esc_url( $image_in_gallery[0] ) . '"';
					}
					?>

					<<?php echo esc_attr( $tag ); ?> <?php echo wp_kses_post( $attr ); ?> class="w-img-item <?php echo esc_attr( $class ); ?>">
						<img src="<?php echo esc_url( $slide_in_gallery[0] ); ?>" <?php echo wp_kses_post( $img_attr ); ?> alt="<?php echo esc_attr( $img_alt ); ?>">
					</<?php echo esc_attr( $tag ); ?>>
					<?php
			endif;
		endforeach;
	endif;
		?>
	</div>
	<?php if ( $gallery_ids && 'list' != $type ) :/*gallery empty*/ ?>
		<div class="w-thumb-crs w-crs">
			<div class="w-thumb-item">
				<img src="<?php echo esc_url( $slide_thumb[0] ); ?>" alt="<?php echo esc_attr( $img_alt ); ?>">
			</div>
			<?php
			foreach ( $gallery_ids as $key ) :
				$thumb = 'list' != $type ? wp_get_attachment_image_src( $key, 'thumbnail' ) : wp_get_attachment_image_src( $key, 'full' );
				if ( $thumb ) :
					$img_alt = minera_img_alt( $key, 'Product image thumbnail' );
					?>
					<div class="w-thumb-item">
						<img src="<?php echo esc_url( $thumb[0] ); ?>" alt="<?php echo esc_attr( $img_alt ); ?>">
					</div>
				<?php endif; ?>
			<?php endforeach; ?>
		</div>
	<?php endif; ?>
</div>

<?php
/*product sticky*/

if ( 'list' == $type ) {
	$offet = true == get_theme_mod( 'sticky', false ) ? 100 : 40;

	wp_enqueue_script( 'minera-product-sticky-content', get_template_directory_uri() . '/js/sticky.min.js', false, true );
	wp_add_inline_script(
		'minera-product-sticky-content',
		"window.addEventListener( 'load', function() {
			var sidebar = new StickySidebar( '.w-summary-box', {
				topSpacing: $offet,
				containerSelector: '.w-data-view .container',
				innerWrapperSelector: '.summary-box-inner',
				minWidth: 992
			});
		} );",
		'after'
	);
}

if ( get_theme_mod('c_shop_lightbox', false ) == true ) {
	wp_add_inline_script(
		'minera-pswp-lightbox-script',
		"$('#{$main_id}').photoSwipe(
		'.w-img-item',
		{
			bgOpacity: 0.9,
			shareEl: false
		});",
		'after'
	);
}
